#!/usr/bin/env python
'''
    This will import data from one updateinfo.xml and produce a
    YAML formatted output.  It does not include all updateinfo
    elements.
'''

from updateinfo.updateinfo import Updateinfo

def UpdateinfoToYAML(info):
    '''
        Create a YAML formatted string representation of an updateinfo entry
    '''
    YAML = 'Synopsis: ' + info.title + '\n'
    YAML = YAML + 'Advisory ID: ' + info.updateid + '\n'
    YAML = YAML + 'Issue Date: ' + str(info.issued_date) + '\n'

    if info.updatetype == 'security':
        YAML = YAML + 'CVE Numbers:\n'
        for ref in info.list_references():
            if info.reference[ref].reftype == 'cve':
                YAML = YAML + '  - ' + info.reference[ref].refid + "\n"

    YAML = YAML + 'Description: >\n  ' + info.description.replace('\n', '\n  ') + '\n'

    for collection in info:
        YAML = YAML + info[collection].short_name + ':\n'
        for pkg in info[collection].pkglist.keys():
            YAML = YAML + '  - ' + pkg + '\n'

    return YAML
        

#############################################################################
if __name__ == "__main__":
    import optparse
    OPTPARSER = optparse.OptionParser()
    (OPTIONS, ARGS) = OPTPARSER.parse_args()

    for FILENAME in ARGS:
        THIS_UPDATEINFO = Updateinfo()
        THIS_UPDATEINFO.from_xml_file(FILENAME)
        print '---'
        for ENTRY in THIS_UPDATEINFO:
            print UpdateinfoToYAML(THIS_UPDATEINFO[ENTRY])
            print '---'
